@@ -11,12 +11,10 @@
 # under the License.
 
 import ipaddress
-import os
 import re
 import subprocess
 
 from oslo_log import log as logging
-import six
 
 from octavia.amphorae.backends.agent.api_server import util
 from octavia.common import constants
@@ -36,10 +34,10 @@ V6_VS_REGEX = re.compile(r"virtual_server\s([\w*:]+\b)\s(\d{1,5})")
 V6_RS_REGEX = re.compile(r"real_server\s([\w*:]+\b)\s(\d{1,5})")
 CONFIG_COMMENT_REGEX = re.compile(
     r"#\sConfiguration\sfor\s(\w+)\s(\w{8}-\w{4}-\w{4}-\w{4}-\w{12})")
-DISABLED_CONFIG_COMMENT_REGEX = re.compile(
-    r"#\s(\w+)\s(\w{8}-\w{4}-\w{4}-\w{4}-\w{12}) is disabled")
+DISABLED_MEMBER_COMMENT_REGEX = re.compile(
+    r"#\sMember\s(\w{8}-\w{4}-\w{4}-\w{4}-\w{12}) is disabled")
 
-CHECKER_REGEX = re.compile(r"MISC_CHECK")
+CHECKER_REGEX = re.compile(r"(MISC_CHECK|HTTP_GET|TCP_CHECK)")
 
 
 def read_kernel_file(ns_name, file_path):
@@ -71,7 +69,7 @@ def get_listener_realserver_mapping(ns_name, listener_ip_port,
     #   'InActConn': 0
     # }}
     listener_ip, listener_port = listener_ip_port.rsplit(':', 1)
-    ip_obj = ipaddress.ip_address(six.text_type(listener_ip.strip('[]')))
+    ip_obj = ipaddress.ip_address(listener_ip.strip('[]'))
     output = read_kernel_file(ns_name, KERNEL_LVS_PATH).split('\n')
     if ip_obj.version == 4:
         ip_to_hex_format = "%.8X" % ip_obj._ip
@@ -153,14 +151,6 @@ def get_udp_listener_resource_ipports_nsname(listener_id):
             listener_ip_port = V6_VS_REGEX.findall(cfg)
         listener_ip_port = listener_ip_port[0] if listener_ip_port else []
 
-        disabled_resource_ids = DISABLED_CONFIG_COMMENT_REGEX.findall(cfg)
-
-        listener_disabled = any(True
-                                for resource in disabled_resource_ids
-                                if resource[0] == 'Listener')
-        if listener_disabled:
-            return None, ns_name
-
         if not listener_ip_port:
             # If not get listener_ip_port from the lvs config file,
             # that means the udp listener's default pool have no enabled member
@@ -190,11 +180,7 @@ def get_udp_listener_resource_ipports_nsname(listener_id):
             elif resource_type == 'Members':
                 resource_ipport_mapping[resource_type].append(value)
 
-        disabled_member_ids = [
-            resource[1]
-            for resource in disabled_resource_ids
-            if resource[0] == 'Member'
-        ]
+        disabled_member_ids = DISABLED_MEMBER_COMMENT_REGEX.findall(cfg)
 
         resource_type = 'Members'
         for member_id in disabled_member_ids:
@@ -207,21 +193,19 @@ def get_udp_listener_resource_ipports_nsname(listener_id):
         if rs_ip_port_list:
             rs_ip_port_count = len(rs_ip_port_list)
             for index in range(rs_ip_port_count):
-                member_ip = ipaddress.ip_address(
-                    six.text_type(rs_ip_port_list[index][0]))
-                if member_ip.version == 6:
+                if ipaddress.ip_address(
+                        rs_ip_port_list[index][0]).version == 6:
                     rs_ip_port_list[index] = (
-                        '[' + member_ip.compressed + ']',
+                        '[' + rs_ip_port_list[index][0] + ']',
                         rs_ip_port_list[index][1])
                 resource_ipport_mapping['Members'][index]['ipport'] = (
                     rs_ip_port_list[index][0] + ':' +
                     rs_ip_port_list[index][1])
 
-        listener_ip = ipaddress.ip_address(
-            six.text_type(listener_ip_port[0]))
-        if listener_ip.version == 6:
+        if ipaddress.ip_address(
+                listener_ip_port[0]).version == 6:
             listener_ip_port = (
-                '[' + listener_ip.compressed + ']', listener_ip_port[1])
+                '[' + listener_ip_port[0] + ']', listener_ip_port[1])
         resource_ipport_mapping['Listener']['ipport'] = (
             listener_ip_port[0] + ':' + listener_ip_port[1])
 
@@ -236,24 +220,10 @@ def get_udp_listener_pool_status(listener_id):
     if 'Members' not in resource_ipport_mapping:
         return {'lvs': {
             'uuid': resource_ipport_mapping['Pool']['id'],
-            'status': constants.UP,
+            'status': constants.DOWN,
             'members': {}
         }}
 
-    config_path = util.keepalived_lvs_cfg_path(listener_id)
-    pids_pathes = util.keepalived_lvs_pids_path(listener_id)
-
-    config_stat = os.stat(config_path)
-    check_pid_stat = os.stat(pids_pathes[2])
-
-    # Indicates that keepalived configuration has been updated but the service
-    # has yet to be restarted.
-    # NOTE: It only works if we are doing a RESTART on configuration change,
-    # Iaa34db6cb1dfed98e96a585c5d105e263c7efa65 forces a RESTART instead of a
-    # RELOAD, we need to be careful if we want to switch back to RELOAD after
-    # updating to a recent keepalived release.
-    restarting = config_stat.st_mtime > check_pid_stat.st_mtime
-
     with open(util.keepalived_lvs_cfg_path(listener_id), 'r') as f:
         cfg = f.read()
         hm_enabled = len(CHECKER_REGEX.findall(cfg)) > 0
@@ -277,8 +247,7 @@ def get_udp_listener_pool_status(listener_id):
             if member_ip_port is None:
                 status = constants.MAINT
             elif member_ip_port in down_member_ip_port_set:
-                status = (
-                    constants.RESTARTING if restarting else constants.DOWN)
+                status = constants.DOWN
             elif int(realserver_result[member_ip_port]['Weight']) == 0:
                 status = constants.DRAIN
             else:
@@ -294,8 +263,7 @@ def get_udp_listener_pool_status(listener_id):
             if member['ipport'] is None:
                 member_results[member['id']] = constants.MAINT
             elif hm_enabled:
-                member_results[member['id']] = (
-                    constants.RESTARTING if restarting else constants.DOWN)
+                member_results[member['id']] = constants.DOWN
             else:
                 member_results[member['id']] = constants.NO_CHECK
 
@@ -394,10 +362,6 @@ def get_udp_listeners_stats():
         (resource_ipport_mapping,
          ns_name) = get_udp_listener_resource_ipports_nsname(check_listener_id)
 
-        # Listener is disabled, we don't need to send an update
-        if resource_ipport_mapping is None:
-            continue
-
         # Since we found the keepalived running, acknowledge the listener
         # in the heartbeat. If this listener has a pool and members,
         # the stats will be updated later in the code flow.
