@@ -12,15 +12,14 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-import ipaddress
 
 from oslo_config import cfg
 from oslo_db import exception as odb_exceptions
 from oslo_log import log as logging
 from oslo_utils import excutils
 from oslo_utils import strutils
-import pecan
-import six
+from pecan import expose as pecan_expose
+from pecan import request as pecan_request
 from sqlalchemy.orm import exc as sa_exception
 from wsme import types as wtypes
 from wsmeext import pecan as wsme_pecan
@@ -58,7 +57,7 @@ class LoadBalancersController(base.BaseController):
                          [wtypes.text], ignore_extra_args=True)
     def get_one(self, id, fields=None):
         """Gets a single load balancer's details."""
-        context = pecan.request.context.get('octavia_context')
+        context = pecan_request.context.get('octavia_context')
         load_balancer = self._get_db_lb(context.session, id,
                                         show_deleted=False)
 
@@ -80,7 +79,7 @@ class LoadBalancersController(base.BaseController):
                          [wtypes.text], ignore_extra_args=True)
     def get_all(self, project_id=None, fields=None):
         """Lists all load balancers."""
-        pcontext = pecan.request.context
+        pcontext = pecan_request.context
         context = pcontext.get('octavia_context')
 
         query_filter = self._auth_get_all(context, project_id)
@@ -188,40 +187,26 @@ class LoadBalancersController(base.BaseController):
                 isinstance(load_balancer.vip_qos_policy_id, wtypes.UnsetType)):
             load_balancer.vip_qos_policy_id = port_qos_policy_id
 
+        # Identify the subnet for this port
         if load_balancer.vip_subnet_id:
-            # If we were provided a subnet_id, validate it exists and that
-            # there is a fixed_ip on the port that matches the provided subnet
             validate.subnet_exists(subnet_id=load_balancer.vip_subnet_id,
                                    context=context)
-            for port_fixed_ip in port.fixed_ips:
-                if port_fixed_ip.subnet_id == load_balancer.vip_subnet_id:
-                    load_balancer.vip_address = port_fixed_ip.ip_address
-                    break  # Just pick the first address found in the subnet
-            if not load_balancer.vip_address:
-                raise exceptions.ValidationException(detail=_(
-                    "No VIP address found on the specified VIP port within "
-                    "the specified subnet."))
-        elif load_balancer.vip_address:
-            normalized_lb_ip = ipaddress.ip_address(
-                six.text_type(load_balancer.vip_address)).compressed
-            for port_fixed_ip in port.fixed_ips:
-                normalized_port_ip = ipaddress.ip_address(
-                    six.text_type(port_fixed_ip.ip_address)).compressed
-                if normalized_port_ip == normalized_lb_ip:
-                    load_balancer.vip_subnet_id = port_fixed_ip.subnet_id
-                    break
-            if not load_balancer.vip_subnet_id:
-                raise exceptions.ValidationException(detail=_(
-                    "Specified VIP address not found on the "
-                    "specified VIP port."))
-        elif len(port.fixed_ips) == 1:
-            # User provided only a port, get the subnet and address from it
-            load_balancer.vip_subnet_id = port.fixed_ips[0].subnet_id
-            load_balancer.vip_address = port.fixed_ips[0].ip_address
         else:
-            raise exceptions.ValidationException(detail=_(
-                "VIP port's subnet could not be determined. Please "
-                "specify either a VIP subnet or address."))
+            if load_balancer.vip_address:
+                for port_fixed_ip in port.fixed_ips:
+                    if port_fixed_ip.ip_address == load_balancer.vip_address:
+                        load_balancer.vip_subnet_id = port_fixed_ip.subnet_id
+                        break
+                if not load_balancer.vip_subnet_id:
+                    raise exceptions.ValidationException(detail=_(
+                        "Specified VIP address not found on the "
+                        "specified VIP port."))
+            elif len(port.fixed_ips) == 1:
+                load_balancer.vip_subnet_id = port.fixed_ips[0].subnet_id
+            else:
+                raise exceptions.ValidationException(detail=_(
+                    "VIP port's subnet could not be determined. Please "
+                    "specify either a VIP subnet or address."))
 
     def _validate_vip_request_object(self, load_balancer, context=None):
         allowed_network_objects = []
@@ -264,12 +249,11 @@ class LoadBalancersController(base.BaseController):
         # Validate just the subnet id
         elif load_balancer.vip_subnet_id:
             subnet = validate.subnet_exists(
-                subnet_id=load_balancer.vip_subnet_id, context=context)
+                subnet_id=load_balancer.vip_subnet_id)
             load_balancer.vip_network_id = subnet.network_id
         if load_balancer.vip_qos_policy_id:
             validate.qos_policy_exists(
                 qos_policy_id=load_balancer.vip_qos_policy_id)
-        validate.network_allowed_by_config(load_balancer.vip_network_id)
 
     def _create_vip_port_if_not_exist(self, load_balancer_db):
         """Create vip port."""
@@ -351,12 +335,52 @@ class LoadBalancersController(base.BaseController):
                 raise exceptions.DisabledOption(option='flavor',
                                                 value=load_balancer.flavor_id)
 
+    def _validate_and_return_az_dict(self, lock_session, driver, lb_dict):
+
+        az_dict = {}
+        if 'availability_zone' in lb_dict:
+            try:
+                az = self.repositories.availability_zone.get(
+                    lock_session, name=lb_dict['availability_zone'])
+                az_dict = (
+                    self.repositories.availability_zone
+                    .get_availability_zone_metadata_dict(lock_session, az.name)
+                )
+            except sa_exception.NoResultFound:
+                raise exceptions.ValidationException(
+                    detail=_("Invalid availability_zone."))
+
+        # Make sure the driver will still accept the availability zone metadata
+        if az_dict:
+            try:
+                driver_utils.call_provider(driver.name,
+                                           driver.validate_availability_zone,
+                                           az_dict)
+            except NotImplementedError:
+                raise exceptions.ProviderNotImplementedError(
+                    prov=driver.name, user_msg="This provider does not support"
+                                               " availability zones.")
+
+        return az_dict
+
+    def _validate_availability_zone(self, session, load_balancer):
+        if not isinstance(load_balancer.availability_zone, wtypes.UnsetType):
+            az = self.repositories.availability_zone.get(
+                session, name=load_balancer.availability_zone)
+            if not az:
+                raise exceptions.ValidationException(
+                    detail=_("Invalid availability zone."))
+            if not az.enabled:
+                raise exceptions.DisabledOption(
+                    option='availability_zone',
+                    value=load_balancer.availability_zone)
+
     @wsme_pecan.wsexpose(lb_types.LoadBalancerFullRootResponse,
                          body=lb_types.LoadBalancerRootPOST, status_code=201)
     def post(self, load_balancer):
         """Creates a load balancer."""
         load_balancer = load_balancer.loadbalancer
-        context = pecan.request.context.get('octavia_context')
+        context = pecan_request.context.get('octavia_context')
 
         if not load_balancer.project_id and context.project_id:
             load_balancer.project_id = context.project_id
@@ -374,6 +398,8 @@ class LoadBalancersController(base.BaseController):
 
         self._validate_flavor(context.session, load_balancer)
 
+        self._validate_availability_zone(context.session, load_balancer)
+
         provider = self._get_provider(context.session, load_balancer)
 
         # Load the driver early as it also provides validation
@@ -406,6 +432,13 @@ class LoadBalancersController(base.BaseController):
             flavor_dict = self._apply_flavor_to_lb_dict(lock_session, driver,
                                                         lb_dict)
 
+            az_dict = self._validate_and_return_az_dict(lock_session, driver,
+                                                        lb_dict)
+            # Validate the network as soon as we have the AZ data
+            validate.network_allowed_by_config(
+                load_balancer.vip_network_id,
+                valid_networks=az_dict.get(constants.VALID_VIP_NETWORKS))
+
             db_lb = self.repositories.create_load_balancer_and_vip(
                 lock_session, lb_dict, vip_dict)
 
@@ -414,10 +447,10 @@ class LoadBalancersController(base.BaseController):
             # flavor dict instead of just the flavor_id we store in the DB.
             lb_dict['flavor'] = flavor_dict
 
-            # See if the provider driver wants to manage the VIP port
-            # This will still be called if the user provided a port to
-            # allow drivers to collect any required information about the
-            # VIP port.
+            # Do the same with the availability_zone dict
+            lb_dict['availability_zone'] = az_dict
+
+            # See if the provider driver wants to create the VIP port
             octavia_owned = False
             try:
                 provider_vip_dict = driver_utils.vip_dict_to_provider_dict(
@@ -437,10 +470,6 @@ class LoadBalancersController(base.BaseController):
                 if 'port_id' not in vip_dict or not vip_dict['port_id']:
                     octavia_owned = True
 
-            # Check if the driver claims octavia owns the VIP port.
-            if vip.octavia_owned:
-                octavia_owned = True
-
             self.repositories.vip.update(
                 lock_session, db_lb.id, ip_address=vip.ip_address,
                 port_id=vip.port_id, network_id=vip.network_id,
@@ -589,7 +618,7 @@ class LoadBalancersController(base.BaseController):
     def put(self, id, load_balancer):
         """Updates a load balancer."""
         load_balancer = load_balancer.loadbalancer
-        context = pecan.request.context.get('octavia_context')
+        context = pecan_request.context.get('octavia_context')
         db_lb = self._get_db_lb(context.session, id, show_deleted=False)
 
         self._auth_validate_action(context, db_lb.project_id,
@@ -647,7 +676,7 @@ class LoadBalancersController(base.BaseController):
     @wsme_pecan.wsexpose(None, wtypes.text, wtypes.text, status_code=204)
     def delete(self, id, cascade=False):
         """Deletes a load balancer."""
-        context = pecan.request.context.get('octavia_context')
+        context = pecan_request.context.get('octavia_context')
         cascade = strutils.bool_from_string(cascade)
         db_lb = self._get_db_lb(context.session, id, show_deleted=False)
 
@@ -674,7 +703,7 @@ class LoadBalancersController(base.BaseController):
             driver_utils.call_provider(driver.name, driver.loadbalancer_delete,
                                        provider_loadbalancer, cascade)
 
-    @pecan.expose()
+    @pecan_expose()
     def _lookup(self, id, *remainder):
         """Overridden pecan _lookup method for custom routing.
 
@@ -713,7 +742,7 @@ class StatusController(base.BaseController):
     @wsme_pecan.wsexpose(lb_types.StatusRootResponse, wtypes.text,
                          status_code=200)
     def get(self):
-        context = pecan.request.context.get('octavia_context')
+        context = pecan_request.context.get('octavia_context')
         load_balancer = self._get_db_lb(context.session, self.id,
                                         show_deleted=False)
         if not load_balancer:
@@ -741,7 +770,7 @@ class StatisticsController(base.BaseController, stats.StatsMixin):
     @wsme_pecan.wsexpose(lb_types.StatisticsRootResponse, wtypes.text,
                          status_code=200)
     def get(self):
-        context = pecan.request.context.get('octavia_context')
+        context = pecan_request.context.get('octavia_context')
         load_balancer = self._get_db_lb(context.session, self.id,
                                         show_deleted=False)
         if not load_balancer:
@@ -769,7 +798,7 @@ class FailoverController(LoadBalancersController):
     @wsme_pecan.wsexpose(None, wtypes.text, status_code=202)
     def put(self, **kwargs):
         """Fails over a loadbalancer"""
-        context = pecan.request.context.get('octavia_context')
+        context = pecan_request.context.get('octavia_context')
         db_lb = self._get_db_lb(context.session, self.lb_id,
                                 show_deleted=False)
 
