@@ -17,7 +17,7 @@ from oslo_db import exception as odb_exceptions
 from oslo_log import log as logging
 from oslo_utils import excutils
 from oslo_utils import strutils
-import pecan
+from pecan import request as pecan_request
 from wsme import types as wtypes
 from wsmeext import pecan as wsme_pecan
 
@@ -48,7 +48,7 @@ class MemberController(base.BaseController):
                          [wtypes.text], ignore_extra_args=True)
     def get(self, id, fields=None):
         """Gets a single pool member's details."""
-        context = pecan.request.context.get('octavia_context')
+        context = pecan_request.context.get('octavia_context')
         db_member = self._get_db_member(context.session, id,
                                         show_deleted=False)
 
@@ -67,7 +67,7 @@ class MemberController(base.BaseController):
                          ignore_extra_args=True)
     def get_all(self, fields=None):
         """Lists all pool members of a pool."""
-        pcontext = pecan.request.context
+        pcontext = pecan_request.context
         context = pcontext.get('octavia_context')
 
         pool = self._get_db_pool(context.session, self.pool_id,
@@ -144,14 +144,7 @@ class MemberController(base.BaseController):
     def post(self, member_):
         """Creates a pool member on a pool."""
         member = member_.member
-        context = pecan.request.context.get('octavia_context')
-
-        pool = self.repositories.pool.get(context.session, id=self.pool_id)
-        member.project_id, provider = self._get_lb_project_id_provider(
-            context.session, pool.load_balancer_id)
-
-        self._auth_validate_action(context, member.project_id,
-                                   constants.RBAC_POST)
+        context = pecan_request.context.get('octavia_context')
 
         validate.ip_not_reserved(member.address)
 
@@ -159,6 +152,12 @@ class MemberController(base.BaseController):
         if (member.subnet_id and
                 not validate.subnet_exists(member.subnet_id, context=context)):
             raise exceptions.NotFound(resource='Subnet', id=member.subnet_id)
+        pool = self.repositories.pool.get(context.session, id=self.pool_id)
+        member.project_id, provider = self._get_lb_project_id_provider(
+            context.session, pool.load_balancer_id)
+
+        self._auth_validate_action(context, member.project_id,
+                                   constants.RBAC_POST)
 
         # Load the driver early as it also provides validation
         driver = driver_factory.get_driver(provider)
@@ -230,9 +229,10 @@ class MemberController(base.BaseController):
     def put(self, id, member_):
         """Updates a pool member."""
         member = member_.member
-        context = pecan.request.context.get('octavia_context')
+        context = pecan_request.context.get('octavia_context')
         db_member = self._get_db_member(context.session, id,
                                         show_deleted=False)
+
         pool = self.repositories.pool.get(context.session,
                                           id=db_member.pool_id)
         project_id, provider = self._get_lb_project_id_provider(
@@ -285,7 +285,7 @@ class MemberController(base.BaseController):
     @wsme_pecan.wsexpose(None, wtypes.text, status_code=204)
     def delete(self, id):
         """Deletes a pool member."""
-        context = pecan.request.context.get('octavia_context')
+        context = pecan_request.context.get('octavia_context')
         db_member = self._get_db_member(context.session, id,
                                         show_deleted=False)
 
@@ -327,7 +327,7 @@ class MembersController(MemberController):
         """Updates all members."""
         members = members_.members
         additive_only = strutils.bool_from_string(additive_only)
-        context = pecan.request.context.get('octavia_context')
+        context = pecan_request.context.get('octavia_context')
 
         db_pool = self._get_db_pool(context.session, self.pool_id)
         old_members = db_pool.members
@@ -428,4 +428,5 @@ class MembersController(MemberController):
             LOG.info("Sending Pool %s batch member update to provider %s",
                      db_pool.id, driver.name)
             driver_utils.call_provider(
-                driver.name, driver.member_batch_update, provider_members)
+                driver.name, driver.member_batch_update, db_pool.id,
+                provider_members)
