@@ -27,11 +27,8 @@ import netaddr
 from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_utils import excutils
-import six
 from stevedore import driver as stevedore_driver
 
-from octavia.common import constants
-
 CONF = cfg.CONF
 
 LOG = logging.getLogger(__name__)
@@ -48,18 +45,7 @@ def base64_sha1_string(string_to_hash):
     # break backwards compatibility with existing loadbalancers.
     hash_str = hashlib.sha1(string_to_hash.encode('utf-8')).digest()  # nosec
     b64_str = base64.b64encode(hash_str, str.encode('_-', 'ascii'))
-    b64_sha1 = b64_str.decode('UTF-8')
-    # https://github.com/haproxy/haproxy/issues/644
-    return re.sub(r"^-", "x", b64_sha1)
-
-
-def get_amphora_driver():
-    amphora_driver = stevedore_driver.DriverManager(
-        namespace='octavia.amphora.drivers',
-        name=CONF.controller_worker.amphora_driver,
-        invoke_on_load=True
-    ).driver
-    return amphora_driver
+    return b64_str.decode('UTF-8')
 
 
 def get_network_driver():
@@ -72,12 +58,6 @@ def get_network_driver():
     return network_driver
 
 
-def is_ipv4(ip_address):
-    """Check if ip address is IPv4 address."""
-    ip = netaddr.IPAddress(ip_address)
-    return ip.version == 4
-
-
 def is_ipv6(ip_address):
     """Check if ip address is IPv6 address."""
     ip = netaddr.IPAddress(ip_address)
@@ -117,21 +97,15 @@ def ip_netmask_to_cidr(ip, netmask):
     return "{ip}/{netmask}".format(ip=net.network, netmask=net.prefixlen)
 
 
-def get_vip_security_group_name(loadbalancer_id):
-    if loadbalancer_id:
-        return constants.VIP_SECURITY_GROUP_PREFIX + loadbalancer_id
-    return None
-
-
-def get_six_compatible_value(value, six_type=six.string_types):
-    if six.PY3 and isinstance(value, six_type):
+def get_compatible_value(value):
+    if isinstance(value, str):
         value = value.encode('utf-8')
     return value
 
 
-def get_six_compatible_server_certs_key_passphrase():
+def get_compatible_server_certs_key_passphrase():
     key = CONF.certificates.server_certs_key_passphrase
-    if six.PY3 and isinstance(key, six.string_types):
+    if isinstance(key, str):
         key = key.encode('utf-8')
     return base64.urlsafe_b64encode(key)
 
@@ -143,6 +117,30 @@ def subnet_ip_availability(nw_ip_avail, subnet_id, req_num_ips):
     return None
 
 
+def b(s):
+    return s.encode('utf-8')
+
+
+def expand_expected_codes(codes):
+    """Expand the expected code string in set of codes.
+
+    200-204 -> 200, 201, 202, 204
+    200, 203 -> 200, 203
+    """
+    retval = set()
+    codes = re.split(', *', codes)
+    for code in codes:
+        if not code:
+            continue
+        if '-' in code:
+            low, hi = code.split('-')[:2]
+            retval.update(
+                str(i) for i in range(int(low), int(hi) + 1))
+        else:
+            retval.add(code)
+    return retval
+
+
 class exception_logger(object):
     """Wrap a function and log raised exception
 
