@@ -51,12 +51,13 @@ class TestHaproxyCfg(base.TestCase):
               "ssl crt-list {crt_list} "
               "ca-file /var/lib/octavia/certs/sample_loadbalancer_id_1/"
               "client_ca.pem verify required crl-file /var/lib/octavia/"
-              "certs/sample_loadbalancer_id_1/SHA_ID.pem\n"
+              "certs/sample_loadbalancer_id_1/SHA_ID.pem ciphers {ciphers}\n"
               "    mode http\n"
               "    default_backend sample_pool_id_1:sample_listener_id_1\n"
               "    timeout client 50000\n").format(
-            maxconn=constants.HAPROXY_DEFAULT_MAXCONN,
-            crt_list=FAKE_CRT_LIST_FILENAME)
+            maxconn=constants.HAPROXY_MAX_MAXCONN,
+            crt_list=FAKE_CRT_LIST_FILENAME,
+            ciphers=constants.CIPHERS_OWASP_SUITE_B)
         be = ("backend sample_pool_id_1:sample_listener_id_1\n"
               "    mode http\n"
               "    balance roundrobin\n"
@@ -74,7 +75,7 @@ class TestHaproxyCfg(base.TestCase):
               "    server sample_member_id_2 10.0.0.98:82 "
               "weight 13 check inter 30s fall 3 rise 2 cookie "
               "sample_member_id_2\n\n").format(
-            maxconn=constants.HAPROXY_DEFAULT_MAXCONN)
+            maxconn=constants.HAPROXY_MAX_MAXCONN)
         tls_tupe = {'cont_id_1':
                     sample_configs_combined.sample_tls_container_tuple(
                         id='tls_container_id',
@@ -94,6 +95,56 @@ class TestHaproxyCfg(base.TestCase):
             rendered_obj)
 
     def test_render_template_tls_no_sni(self):
+        conf = oslo_fixture.Config(cfg.CONF)
+        conf.config(group="haproxy_amphora", base_cert_dir='/fake_cert_dir')
+        FAKE_CRT_LIST_FILENAME = os.path.join(
+            CONF.haproxy_amphora.base_cert_dir,
+            'sample_loadbalancer_id_1/sample_listener_id_1.pem')
+        fe = ("frontend sample_listener_id_1\n"
+              "    maxconn {maxconn}\n"
+              "    redirect scheme https if !{{ ssl_fc }}\n"
+              "    bind 10.0.0.2:443 ssl crt-list {crt_list}"
+              "   ciphers {ciphers}\n"
+              "    mode http\n"
+              "    default_backend sample_pool_id_1:sample_listener_id_1\n"
+              "    timeout client 50000\n").format(
+            maxconn=constants.HAPROXY_MAX_MAXCONN,
+            crt_list=FAKE_CRT_LIST_FILENAME,
+            ciphers=constants.CIPHERS_OWASP_SUITE_B)
+        be = ("backend sample_pool_id_1:sample_listener_id_1\n"
+              "    mode http\n"
+              "    balance roundrobin\n"
+              "    cookie SRV insert indirect nocache\n"
+              "    timeout check 31s\n"
+              "    option httpchk GET /index.html HTTP/1.0\\r\\n\n"
+              "    http-check expect rstatus 418\n"
+              "    fullconn {maxconn}\n"
+              "    option allbackups\n"
+              "    timeout connect 5000\n"
+              "    timeout server 50000\n"
+              "    server sample_member_id_1 10.0.0.99:82 "
+              "weight 13 check inter 30s fall 3 rise 2 "
+              "cookie sample_member_id_1\n"
+              "    server sample_member_id_2 10.0.0.98:82 "
+              "weight 13 check inter 30s fall 3 rise 2 "
+              "cookie sample_member_id_2\n\n").format(
+            maxconn=constants.HAPROXY_MAX_MAXCONN)
+        rendered_obj = self.jinja_cfg.render_loadbalancer_obj(
+            sample_configs_combined.sample_amphora_tuple(),
+            [sample_configs_combined.sample_listener_tuple(
+                proto='TERMINATED_HTTPS', tls=True)],
+            tls_certs={'cont_id_1':
+                       sample_configs_combined.sample_tls_container_tuple(
+                           id='tls_container_id',
+                           certificate='ImAalsdkfjCert',
+                           private_key='ImAsdlfksdjPrivateKey',
+                           primary_cn="FakeCN")})
+        self.assertEqual(
+            sample_configs_combined.sample_base_expected_config(
+                frontend=fe, backend=be),
+            rendered_obj)
+
+    def test_render_template_tls_no_ciphers(self):
         conf = oslo_fixture.Config(cfg.CONF)
         conf.config(group="haproxy_amphora", base_cert_dir='/fake_cert_dir')
         FAKE_CRT_LIST_FILENAME = os.path.join(
@@ -106,7 +157,7 @@ class TestHaproxyCfg(base.TestCase):
               "    mode http\n"
               "    default_backend sample_pool_id_1:sample_listener_id_1\n"
               "    timeout client 50000\n").format(
-            maxconn=constants.HAPROXY_DEFAULT_MAXCONN,
+            maxconn=constants.HAPROXY_MAX_MAXCONN,
             crt_list=FAKE_CRT_LIST_FILENAME)
         be = ("backend sample_pool_id_1:sample_listener_id_1\n"
               "    mode http\n"
@@ -125,11 +176,11 @@ class TestHaproxyCfg(base.TestCase):
               "    server sample_member_id_2 10.0.0.98:82 "
               "weight 13 check inter 30s fall 3 rise 2 "
               "cookie sample_member_id_2\n\n").format(
-            maxconn=constants.HAPROXY_DEFAULT_MAXCONN)
+            maxconn=constants.HAPROXY_MAX_MAXCONN)
         rendered_obj = self.jinja_cfg.render_loadbalancer_obj(
             sample_configs_combined.sample_amphora_tuple(),
             [sample_configs_combined.sample_listener_tuple(
-                proto='TERMINATED_HTTPS', tls=True)],
+                proto='TERMINATED_HTTPS', tls=True, tls_ciphers=None)],
             tls_certs={'cont_id_1':
                        sample_configs_combined.sample_tls_container_tuple(
                            id='tls_container_id',
@@ -159,7 +210,7 @@ class TestHaproxyCfg(base.TestCase):
               "    server sample_member_id_2 10.0.0.98:82 "
               "weight 13 check inter 30s fall 3 rise 2 "
               "cookie sample_member_id_2\n\n").format(
-            maxconn=constants.HAPROXY_DEFAULT_MAXCONN)
+            maxconn=constants.HAPROXY_MAX_MAXCONN)
         rendered_obj = self.jinja_cfg.render_loadbalancer_obj(
             sample_configs_combined.sample_amphora_tuple(),
             [sample_configs_combined.sample_listener_tuple()])
@@ -187,7 +238,7 @@ class TestHaproxyCfg(base.TestCase):
               "weight 13 check inter 30s fall 3 rise 2 "
               "addr 192.168.1.1 port 9000 "
               "cookie sample_member_id_2 backup\n\n").format(
-            maxconn=constants.HAPROXY_DEFAULT_MAXCONN)
+            maxconn=constants.HAPROXY_MAX_MAXCONN)
         rendered_obj = self.jinja_cfg.render_loadbalancer_obj(
             sample_configs_combined.sample_amphora_tuple(),
             [sample_configs_combined.sample_listener_tuple(
@@ -203,7 +254,7 @@ class TestHaproxyCfg(base.TestCase):
               "    mode http\n"
               "    default_backend sample_pool_id_1:sample_listener_id_1\n"
               "    timeout client 2\n").format(
-            maxconn=constants.HAPROXY_DEFAULT_MAXCONN)
+            maxconn=constants.HAPROXY_MAX_MAXCONN)
         be = ("backend sample_pool_id_1:sample_listener_id_1\n"
               "    mode http\n"
               "    balance roundrobin\n"
@@ -220,7 +271,7 @@ class TestHaproxyCfg(base.TestCase):
               "    server sample_member_id_2 10.0.0.98:82 weight 13 "
               "check inter 30s fall 3 rise 2 cookie "
               "sample_member_id_2\n\n").format(
-            maxconn=constants.HAPROXY_DEFAULT_MAXCONN)
+            maxconn=constants.HAPROXY_MAX_MAXCONN)
         rendered_obj = self.jinja_cfg.render_loadbalancer_obj(
             sample_configs_combined.sample_amphora_tuple(),
             [sample_configs_combined.sample_listener_tuple(
@@ -238,7 +289,7 @@ class TestHaproxyCfg(base.TestCase):
               "    mode http\n"
               "    default_backend sample_pool_id_1:sample_listener_id_1\n"
               "    timeout client 50000\n").format(
-            maxconn=constants.HAPROXY_DEFAULT_MAXCONN)
+            maxconn=constants.HAPROXY_MAX_MAXCONN)
         be = ("backend sample_pool_id_1:sample_listener_id_1\n"
               "    mode http\n"
               "    balance roundrobin\n"
@@ -255,7 +306,7 @@ class TestHaproxyCfg(base.TestCase):
               "    server sample_member_id_2 10.0.0.98:82 weight 13 "
               "check inter 30s fall 3 rise 2 cookie "
               "sample_member_id_2\n\n").format(
-            maxconn=constants.HAPROXY_DEFAULT_MAXCONN)
+            maxconn=constants.HAPROXY_MAX_MAXCONN)
         rendered_obj = self.jinja_cfg.render_loadbalancer_obj(
             sample_configs_combined.sample_amphora_tuple(),
             [sample_configs_combined.sample_listener_tuple(
@@ -286,7 +337,7 @@ class TestHaproxyCfg(base.TestCase):
               "weight 13 check inter 30s fall 3 rise 2 "
               "addr 192.168.1.1 port 9000 "
               "cookie sample_member_id_2\n\n").format(
-            maxconn=constants.HAPROXY_DEFAULT_MAXCONN)
+            maxconn=constants.HAPROXY_MAX_MAXCONN)
         rendered_obj = self.jinja_cfg.render_loadbalancer_obj(
             sample_configs_combined.sample_amphora_tuple(),
             [sample_configs_combined.sample_listener_tuple(
@@ -302,7 +353,7 @@ class TestHaproxyCfg(base.TestCase):
               "    mode tcp\n"
               "    default_backend sample_pool_id_1:sample_listener_id_1\n"
               "    timeout client 50000\n").format(
-            maxconn=constants.HAPROXY_DEFAULT_MAXCONN)
+            maxconn=constants.HAPROXY_MAX_MAXCONN)
         lg = ("    log-format 12345\\ sample_loadbalancer_id_1\\ %f\\ "
               "%ci\\ %cp\\ %t\\ -\\ -\\ %B\\ %U\\ "
               "%[ssl_c_verify]\\ %{+Q}[ssl_c_s_dn]\\ %b\\ %s\\ %Tt\\ "
@@ -324,7 +375,7 @@ class TestHaproxyCfg(base.TestCase):
               "    server sample_member_id_2 10.0.0.98:82 "
               "weight 13 check check-ssl verify none inter 30s fall 3 rise 2 "
               "cookie sample_member_id_2\n\n").format(
-            maxconn=constants.HAPROXY_DEFAULT_MAXCONN)
+            maxconn=constants.HAPROXY_MAX_MAXCONN)
         rendered_obj = self.jinja_cfg.render_loadbalancer_obj(
             sample_configs_combined.sample_amphora_tuple(),
             [sample_configs_combined.sample_listener_tuple(proto='HTTPS')])
@@ -338,7 +389,7 @@ class TestHaproxyCfg(base.TestCase):
               "    mode tcp\n"
               "    default_backend sample_pool_id_1:sample_listener_id_1\n"
               "    timeout client 50000\n").format(
-            maxconn=constants.HAPROXY_DEFAULT_MAXCONN)
+            maxconn=constants.HAPROXY_MAX_MAXCONN)
         lg = ("    log-format 12345\\ sample_loadbalancer_id_1\\ %f\\ "
               "%ci\\ %cp\\ %t\\ -\\ -\\ %B\\ %U\\ "
               "%[ssl_c_verify]\\ %{+Q}[ssl_c_s_dn]\\ %b\\ %s\\ %Tt\\ "
@@ -359,7 +410,7 @@ class TestHaproxyCfg(base.TestCase):
               "    server sample_member_id_2 10.0.0.98:82 "
               "weight 13 check inter 30s fall 3 rise 2 "
               "cookie sample_member_id_2\n\n").format(
-            maxconn=constants.HAPROXY_DEFAULT_MAXCONN)
+            maxconn=constants.HAPROXY_MAX_MAXCONN)
         rendered_obj = self.jinja_cfg.render_loadbalancer_obj(
             sample_configs_combined.sample_amphora_tuple(),
             [sample_configs_combined.sample_listener_tuple(
@@ -380,7 +431,7 @@ class TestHaproxyCfg(base.TestCase):
               "cookie sample_member_id_1\n"
               "    server sample_member_id_2 10.0.0.98:82 weight 13 "
               "cookie sample_member_id_2\n\n").format(
-            maxconn=constants.HAPROXY_DEFAULT_MAXCONN)
+            maxconn=constants.HAPROXY_MAX_MAXCONN)
         rendered_obj = self.jinja_cfg.render_loadbalancer_obj(
             sample_configs_combined.sample_amphora_tuple(),
             [sample_configs_combined.sample_listener_tuple(proto='HTTP',
@@ -401,7 +452,7 @@ class TestHaproxyCfg(base.TestCase):
               "cookie sample_member_id_1\n"
               "    server sample_member_id_2 10.0.0.98:82 weight 13 "
               "cookie sample_member_id_2 disabled\n\n").format(
-            maxconn=constants.HAPROXY_DEFAULT_MAXCONN)
+            maxconn=constants.HAPROXY_MAX_MAXCONN)
         rendered_obj = self.jinja_cfg.render_loadbalancer_obj(
             sample_configs_combined.sample_amphora_tuple(),
             [sample_configs_combined.sample_listener_tuple(
@@ -427,9 +478,9 @@ class TestHaproxyCfg(base.TestCase):
               "    server sample_member_id_2 10.0.0.98:82 "
               "weight 13 check inter 30s fall 3 rise 2 "
               "cookie sample_member_id_2\n\n").format(
-            maxconn=constants.HAPROXY_DEFAULT_MAXCONN)
+            maxconn=constants.HAPROXY_MAX_MAXCONN)
         go = "    maxconn {maxconn}\n    external-check\n\n".format(
-            maxconn=constants.HAPROXY_DEFAULT_MAXCONN)
+            maxconn=constants.HAPROXY_MAX_MAXCONN)
         rendered_obj = self.jinja_cfg.render_loadbalancer_obj(
             sample_configs_combined.sample_amphora_tuple(),
             [sample_configs_combined.sample_listener_tuple(
@@ -444,7 +495,7 @@ class TestHaproxyCfg(base.TestCase):
               "    mode tcp\n"
               "    default_backend sample_pool_id_1:sample_listener_id_1\n"
               "    timeout client 50000\n").format(
-            maxconn=constants.HAPROXY_DEFAULT_MAXCONN)
+            maxconn=constants.HAPROXY_MAX_MAXCONN)
         lg = ("    log-format 12345\\ sample_loadbalancer_id_1\\ %f\\ "
               "%ci\\ %cp\\ %t\\ -\\ -\\ %B\\ %U\\ "
               "%[ssl_c_verify]\\ %{+Q}[ssl_c_s_dn]\\ %b\\ %s\\ %Tt\\ "
@@ -461,7 +512,7 @@ class TestHaproxyCfg(base.TestCase):
               "cookie sample_member_id_1\n"
               "    server sample_member_id_2 10.0.0.98:82 weight 13 "
               "cookie sample_member_id_2\n\n").format(
-            maxconn=constants.HAPROXY_DEFAULT_MAXCONN)
+            maxconn=constants.HAPROXY_MAX_MAXCONN)
         rendered_obj = self.jinja_cfg.render_loadbalancer_obj(
             sample_configs_combined.sample_amphora_tuple(),
             [sample_configs_combined.sample_listener_tuple(proto='HTTPS',
@@ -488,7 +539,7 @@ class TestHaproxyCfg(base.TestCase):
               "    server sample_member_id_2 10.0.0.98:82 "
               "weight 13 check inter 30s fall 3 rise 2 "
               "cookie sample_member_id_2\n\n").format(
-            maxconn=constants.HAPROXY_DEFAULT_MAXCONN)
+            maxconn=constants.HAPROXY_MAX_MAXCONN)
         rendered_obj = self.jinja_cfg.render_loadbalancer_obj(
             sample_configs_combined.sample_amphora_tuple(),
             [sample_configs_combined.sample_listener_tuple(
@@ -503,7 +554,7 @@ class TestHaproxyCfg(base.TestCase):
               "    mode tcp\n"
               "    default_backend sample_pool_id_1:sample_listener_id_1\n"
               "    timeout client 50000\n").format(
-            maxconn=constants.HAPROXY_DEFAULT_MAXCONN)
+            maxconn=constants.HAPROXY_MAX_MAXCONN)
         lg = ("    log-format 12345\\ sample_loadbalancer_id_1\\ %f\\ "
               "%ci\\ %cp\\ %t\\ -\\ -\\ %B\\ %U\\ "
               "%[ssl_c_verify]\\ %{+Q}[ssl_c_s_dn]\\ %b\\ %s\\ %Tt\\ "
@@ -517,8 +568,7 @@ class TestHaproxyCfg(base.TestCase):
               "    timeout server 50000\n"
               "    server sample_member_id_1 10.0.0.99:82 weight 13\n"
               "    server sample_member_id_2 10.0.0.98:82 "
-              "weight 13\n\n").format(
-                  maxconn=constants.HAPROXY_DEFAULT_MAXCONN)
+              "weight 13\n\n").format(maxconn=constants.HAPROXY_MAX_MAXCONN)
         rendered_obj = self.jinja_cfg.render_loadbalancer_obj(
             sample_configs_combined.sample_amphora_tuple(),
             [sample_configs_combined.sample_listener_tuple(
@@ -536,8 +586,7 @@ class TestHaproxyCfg(base.TestCase):
               "    timeout server 50000\n"
               "    server sample_member_id_1 10.0.0.99:82 weight 13\n"
               "    server sample_member_id_2 10.0.0.98:82 "
-              "weight 13\n\n").format(
-                  maxconn=constants.HAPROXY_DEFAULT_MAXCONN)
+              "weight 13\n\n").format(maxconn=constants.HAPROXY_MAX_MAXCONN)
         rendered_obj = self.jinja_cfg.render_loadbalancer_obj(
             sample_configs_combined.sample_amphora_tuple(),
             [sample_configs_combined.sample_listener_tuple(
@@ -562,7 +611,7 @@ class TestHaproxyCfg(base.TestCase):
               "weight 13 check inter 30s fall 3 rise 2\n"
               "    server sample_member_id_2 10.0.0.98:82 "
               "weight 13 check inter 30s fall 3 rise 2\n\n").format(
-            maxconn=constants.HAPROXY_DEFAULT_MAXCONN)
+            maxconn=constants.HAPROXY_MAX_MAXCONN)
         rendered_obj = self.jinja_cfg.render_loadbalancer_obj(
             sample_configs_combined.sample_amphora_tuple(),
             [sample_configs_combined.sample_listener_tuple(
@@ -589,7 +638,7 @@ class TestHaproxyCfg(base.TestCase):
               "weight 13 check inter 30s fall 3 rise 2\n"
               "    server sample_member_id_2 10.0.0.98:82 "
               "weight 13 check inter 30s fall 3 rise 2\n\n").format(
-            maxconn=constants.HAPROXY_DEFAULT_MAXCONN)
+            maxconn=constants.HAPROXY_MAX_MAXCONN)
         rendered_obj = self.jinja_cfg.render_loadbalancer_obj(
             sample_configs_combined.sample_amphora_tuple(),
             [sample_configs_combined.sample_listener_tuple(
@@ -609,7 +658,7 @@ class TestHaproxyCfg(base.TestCase):
               "    mode tcp\n"
               "    default_backend {pool_id}:{listener_id}\n"
               "    timeout client 50000\n").format(
-            maxconn=constants.HAPROXY_DEFAULT_MAXCONN,
+            maxconn=constants.HAPROXY_MAX_MAXCONN,
             pool_id=sample_listener.default_pool.id,
             listener_id=sample_listener.id)
         lg = ("    log-format 12345\\ sample_loadbalancer_id_1\\ %f\\ "
@@ -628,7 +677,7 @@ class TestHaproxyCfg(base.TestCase):
               "cookie sample_member_id_1\n"
               "    server sample_member_id_2 10.0.0.98:82 weight 13 "
               "cookie sample_member_id_2\n\n").format(
-            maxconn=constants.HAPROXY_DEFAULT_MAXCONN,
+            maxconn=constants.HAPROXY_MAX_MAXCONN,
             pool_id=sample_listener.default_pool.id,
             listener_id=sample_listener.id)
         rendered_obj = self.jinja_cfg.render_loadbalancer_obj(
@@ -696,7 +745,7 @@ class TestHaproxyCfg(base.TestCase):
               "!sample_l7rule_id_2 sample_l7rule_id_3\n"
               "    default_backend sample_pool_id_1:sample_listener_id_1\n"
               "    timeout client 50000\n").format(
-            maxconn=constants.HAPROXY_DEFAULT_MAXCONN)
+            maxconn=constants.HAPROXY_MAX_MAXCONN)
         be = ("backend sample_pool_id_1:sample_listener_id_1\n"
               "    mode http\n"
               "    balance roundrobin\n"
@@ -726,7 +775,7 @@ class TestHaproxyCfg(base.TestCase):
               "    timeout server 50000\n"
               "    server sample_member_id_3 10.0.0.97:82 weight 13 check "
               "inter 30s fall 3 rise 2 cookie sample_member_id_3\n\n").format(
-            maxconn=constants.HAPROXY_DEFAULT_MAXCONN)
+            maxconn=constants.HAPROXY_MAX_MAXCONN)
         rendered_obj = self.jinja_cfg.render_loadbalancer_obj(
             sample_configs_combined.sample_amphora_tuple(),
             [sample_configs_combined.sample_listener_tuple(l7=True)])
@@ -752,7 +801,7 @@ class TestHaproxyCfg(base.TestCase):
               "    server sample_member_id_2 10.0.0.98:82 "
               "weight 13 check inter 30s fall 3 rise 2 "
               "cookie sample_member_id_2\n\n").format(
-            maxconn=constants.HAPROXY_DEFAULT_MAXCONN)
+            maxconn=constants.HAPROXY_MAX_MAXCONN)
         rendered_obj = self.jinja_cfg.render_loadbalancer_obj(
             sample_configs_combined.sample_amphora_tuple(),
             [sample_configs_combined.sample_listener_tuple(
@@ -781,7 +830,7 @@ class TestHaproxyCfg(base.TestCase):
               "    server sample_member_id_2 10.0.0.98:82 "
               "weight 13 check inter 30s fall 3 rise 2 "
               "cookie sample_member_id_2\n\n").format(
-            maxconn=constants.HAPROXY_DEFAULT_MAXCONN)
+            maxconn=constants.HAPROXY_MAX_MAXCONN)
         rendered_obj = self.jinja_cfg.render_loadbalancer_obj(
             sample_configs_combined.sample_amphora_tuple(),
             [sample_configs_combined.sample_listener_tuple(
@@ -807,7 +856,7 @@ class TestHaproxyCfg(base.TestCase):
               "    server sample_member_id_2 10.0.0.98:82 "
               "weight 13 check inter 30s fall 3 rise 2 "
               "cookie sample_member_id_2 send-proxy\n\n").format(
-            maxconn=constants.HAPROXY_DEFAULT_MAXCONN)
+            maxconn=constants.HAPROXY_MAX_MAXCONN)
         rendered_obj = self.jinja_cfg.render_loadbalancer_obj(
             sample_configs_combined.sample_amphora_tuple(),
             [sample_configs_combined.sample_listener_tuple(be_proto='PROXY')])
@@ -835,7 +884,43 @@ class TestHaproxyCfg(base.TestCase):
               "    server sample_member_id_2 10.0.0.98:82 weight 13 "
               "check inter 30s fall 3 rise 2 cookie sample_member_id_2 "
               "{opts}\n\n").format(
-            maxconn=constants.HAPROXY_DEFAULT_MAXCONN,
+            maxconn=constants.HAPROXY_MAX_MAXCONN,
+            opts="ssl crt %s verify none sni ssl_fc_sni" % cert_file_path +
+                 " ciphers " + constants.CIPHERS_OWASP_SUITE_B)
+        rendered_obj = self.jinja_cfg.render_loadbalancer_obj(
+            sample_configs_combined.sample_amphora_tuple(),
+            [sample_configs_combined.sample_listener_tuple(
+                pool_cert=True, tls_enabled=True,
+                backend_tls_ciphers=constants.CIPHERS_OWASP_SUITE_B)],
+            tls_certs={
+                'sample_pool_id_1':
+                    {'client_cert': cert_file_path,
+                     'ca_cert': None, 'crl': None}})
+        self.assertEqual(
+            sample_configs_combined.sample_base_expected_config(backend=be),
+            rendered_obj)
+
+    def test_render_template_pool_cert_no_ciphers(self):
+        cert_file_path = os.path.join(self.jinja_cfg.base_crt_dir,
+                                      'sample_listener_id_1', 'fake path')
+        be = ("backend sample_pool_id_1:sample_listener_id_1\n"
+              "    mode http\n"
+              "    balance roundrobin\n"
+              "    cookie SRV insert indirect nocache\n"
+              "    timeout check 31s\n"
+              "    option httpchk GET /index.html HTTP/1.0\\r\\n\n"
+              "    http-check expect rstatus 418\n"
+              "    fullconn {maxconn}\n"
+              "    option allbackups\n"
+              "    timeout connect 5000\n"
+              "    timeout server 50000\n"
+              "    server sample_member_id_1 10.0.0.99:82 weight 13 "
+              "check inter 30s fall 3 rise 2 cookie sample_member_id_1 "
+              "{opts}\n"
+              "    server sample_member_id_2 10.0.0.98:82 weight 13 "
+              "check inter 30s fall 3 rise 2 cookie sample_member_id_2 "
+              "{opts}\n\n").format(
+            maxconn=constants.HAPROXY_MAX_MAXCONN,
             opts="ssl crt %s verify none sni ssl_fc_sni" % cert_file_path)
         rendered_obj = self.jinja_cfg.render_loadbalancer_obj(
             sample_configs_combined.sample_amphora_tuple(),
@@ -870,7 +955,7 @@ class TestHaproxyCfg(base.TestCase):
               "    server sample_member_id_2 10.0.0.98:82 weight 13 "
               "check inter 30s fall 3 rise 2 cookie sample_member_id_2 "
               "{opts}\n\n").format(
-            maxconn=constants.HAPROXY_DEFAULT_MAXCONN,
+            maxconn=constants.HAPROXY_MAX_MAXCONN,
             opts="%s %s %s %s %s %s" % (
                 "ssl", "crt", pool_client_cert,
                 "ca-file %s" % pool_ca_cert,
@@ -955,41 +1040,6 @@ class TestHaproxyCfg(base.TestCase):
             in_amphora, in_listener.load_balancer, [in_listener], None, {})
         self.assertEqual(sample_configs_combined.RET_LB, ret)
 
-    def test_transform_two_loadbalancers(self):
-        in_amphora = sample_configs_combined.sample_amphora_tuple()
-        in_listener1 = sample_configs_combined.sample_listener_tuple()
-        in_listener2 = sample_configs_combined.sample_listener_tuple()
-
-        ret = self.jinja_cfg._transform_loadbalancer(
-            in_amphora, in_listener1.load_balancer,
-            [in_listener1, in_listener2], None, {})
-        self.assertEqual(ret['global_connection_limit'],
-                         constants.HAPROXY_DEFAULT_MAXCONN +
-                         constants.HAPROXY_DEFAULT_MAXCONN)
-
-    def test_transform_many_loadbalancers(self):
-        in_amphora = sample_configs_combined.sample_amphora_tuple()
-
-        in_listeners = []
-
-        # Create many listeners, until the sum of connection_limits
-        # is greater than MAX_MAXCONN
-        connection_limit_sum = 0
-        while connection_limit_sum <= constants.HAPROXY_MAX_MAXCONN:
-            in_listener = (
-                sample_configs_combined.sample_listener_tuple())
-            connection_limit_sum += constants.HAPROXY_DEFAULT_MAXCONN
-
-            in_listeners.append(in_listener)
-
-        ret = self.jinja_cfg._transform_loadbalancer(
-            in_amphora, in_listeners[0].load_balancer,
-            in_listeners, None, {})
-        self.assertEqual(ret['global_connection_limit'],
-                         constants.HAPROXY_MAX_MAXCONN)
-        self.assertLess(ret['global_connection_limit'],
-                        connection_limit_sum)
-
     def test_transform_amphora(self):
         in_amphora = sample_configs_combined.sample_amphora_tuple()
         ret = self.jinja_cfg._transform_amphora(in_amphora, {})
@@ -1036,35 +1086,6 @@ class TestHaproxyCfg(base.TestCase):
         self.assertEqual(self.jinja_cfg._escape_haproxy_config_string(
             'string\\ with\\ all'), 'string\\\\\\ with\\\\\\ all')
 
-    def test_expand_expected_codes(self):
-        exp_codes = ''
-        self.assertEqual(self.jinja_cfg._expand_expected_codes(exp_codes),
-                         [])
-        exp_codes = '200'
-        self.assertEqual(
-            self.jinja_cfg._expand_expected_codes(exp_codes), ['200'])
-        exp_codes = '200, 201'
-        self.assertEqual(self.jinja_cfg._expand_expected_codes(exp_codes),
-                         ['200', '201'])
-        exp_codes = '200, 201,202'
-        self.assertEqual(self.jinja_cfg._expand_expected_codes(exp_codes),
-                         ['200', '201', '202'])
-        exp_codes = '200-202'
-        self.assertEqual(self.jinja_cfg._expand_expected_codes(exp_codes),
-                         ['200', '201', '202'])
-        exp_codes = '200-202, 205'
-        self.assertEqual(self.jinja_cfg._expand_expected_codes(exp_codes),
-                         ['200', '201', '202', '205'])
-        exp_codes = '200, 201-203'
-        self.assertEqual(self.jinja_cfg._expand_expected_codes(exp_codes),
-                         ['200', '201', '202', '203'])
-        exp_codes = '200, 201-203, 205'
-        self.assertEqual(self.jinja_cfg._expand_expected_codes(exp_codes),
-                         ['200', '201', '202', '203', '205'])
-        exp_codes = '201-200, 205'
-        self.assertEqual(
-            self.jinja_cfg._expand_expected_codes(exp_codes), ['205'])
-
     def test_render_template_no_log(self):
         j_cfg = jinja_cfg.JinjaTemplater(
             base_amp_path='/var/lib/octavia',
@@ -1111,7 +1132,7 @@ class TestHaproxyCfg(base.TestCase):
               "    server sample_member_id_2 10.0.0.98:82 "
               "weight 13 check inter 30s fall 3 rise 2 "
               "cookie sample_member_id_2 send-proxy\n\n").format(
-            maxconn=constants.HAPROXY_DEFAULT_MAXCONN,
+            maxconn=constants.HAPROXY_MAX_MAXCONN,
             pool_id=sample_proxy_listener.default_pool.id,
             listener_id=sample_proxy_listener.id)
         rendered_obj = j_cfg.build_config(
@@ -1139,7 +1160,7 @@ class TestHaproxyCfg(base.TestCase):
               "    server sample_member_id_2 10.0.0.98:82 "
               "weight 13 check inter 30s fall 3 rise 2 "
               "cookie sample_member_id_2 send-proxy\n\n").format(
-            maxconn=constants.HAPROXY_DEFAULT_MAXCONN,
+            maxconn=constants.HAPROXY_MAX_MAXCONN,
             pool_id=sample_proxy_listener.default_pool.id,
             listener_id=sample_proxy_listener.id)
         rendered_obj = j_cfg.build_config(
@@ -1156,9 +1177,10 @@ class TestHaproxyCfg(base.TestCase):
             base_amp_path='/var/lib/octavia',
             base_crt_dir='/var/lib/octavia/certs')
         fe = ("frontend sample_listener_id_1\n"
-              "    maxconn {maxconn}\n"
-              "    redirect scheme https if !{{ ssl_fc }}\n"
-              "    bind 10.0.0.2:443\n"
+              "    maxconn 1000000\n"
+              "    redirect scheme https if !{ ssl_fc }\n"
+              "    bind 10.0.0.2:443 ciphers " +
+              constants.CIPHERS_OWASP_SUITE_B + "\n"
               "    mode http\n"
               "        acl sample_l7rule_id_1 path -m beg /api\n"
               "    use_backend sample_pool_id_2:sample_listener_id_1"
@@ -1192,8 +1214,7 @@ class TestHaproxyCfg(base.TestCase):
               "if sample_l7rule_id_7 !sample_l7rule_id_8 !sample_l7rule_id_9 "
               "!sample_l7rule_id_10 sample_l7rule_id_11\n"
               "    default_backend sample_pool_id_1:sample_listener_id_1\n"
-              "    timeout client 50000\n".format(
-                  maxconn=constants.HAPROXY_DEFAULT_MAXCONN))
+              "    timeout client 50000\n")
         be = ("backend sample_pool_id_1:sample_listener_id_1\n"
               "    mode http\n"
               "    balance roundrobin\n"
@@ -1201,7 +1222,7 @@ class TestHaproxyCfg(base.TestCase):
               "    timeout check 31s\n"
               "    option httpchk GET /index.html HTTP/1.0\\r\\n\n"
               "    http-check expect rstatus 418\n"
-              "    fullconn {maxconn}\n"
+              "    fullconn 1000000\n"
               "    option allbackups\n"
               "    timeout connect 5000\n"
               "    timeout server 50000\n"
@@ -1216,13 +1237,12 @@ class TestHaproxyCfg(base.TestCase):
               "    timeout check 31s\n"
               "    option httpchk GET /healthmon.html HTTP/1.0\\r\\n\n"
               "    http-check expect rstatus 418\n"
-              "    fullconn {maxconn}\n"
+              "    fullconn 1000000\n"
               "    option allbackups\n"
               "    timeout connect 5000\n"
               "    timeout server 50000\n"
               "    server sample_member_id_3 10.0.0.97:82 weight 13 check "
-              "inter 30s fall 3 rise 2 cookie sample_member_id_3\n\n".format(
-                  maxconn=constants.HAPROXY_DEFAULT_MAXCONN))
+              "inter 30s fall 3 rise 2 cookie sample_member_id_3\n\n")
         sample_listener = sample_configs_combined.sample_listener_tuple(
             proto=constants.PROTOCOL_TERMINATED_HTTPS, l7=True,
             ssl_type_l7=True)
